

set -ex



test -f $PREFIX/libexec/as/x86_64/as
test -f $PREFIX/bin/x86_64-apple-darwin13.4.0-as
test -f $PREFIX/bin/x86_64-apple-darwin13.4.0-ranlib
test -f $PREFIX/bin/x86_64-apple-darwin13.4.0-ld
test -f $PREFIX/bin/x86_64-apple-darwin13.4.0-ar
test -f $PREFIX/bin/x86_64-apple-darwin13.4.0-otool
$PREFIX/bin/x86_64-apple-darwin13.4.0-otool -l $PREFIX/bin/x86_64-apple-darwin13.4.0-otool
test -f $PREFIX/bin/x86_64-apple-darwin13.4.0-install_name_tool
test -f $PREFIX/bin/x86_64-apple-darwin13.4.0-strip
exit 0
